@@ -42,8 +42,9 @@ SUPPORTED_GENOMES = ["GRCh37", "hg19", "hg38", "hg38-noalt", "mm10", "mm9",
                      "pseudomonas_aeruginosa_ucbpp_pa14", "sacCer3", "TAIR10",
                      "WBcel235", "xenTro3", "GRCz10", "GRCz11", "Sscrofa11.1", "BDGP6"]
 TARBALL_DIRECTORIES = ["bwa", "rtg", "hisat2"]
-SUPPORTED_INDEXES = TARBALL_DIRECTORIES + ["bbmap", "bowtie", "bowtie2", "minimap2", "novoalign", "twobit",
-                                           "snap", "star", "seq"]
+SUPPORTED_INDEXES = TARBALL_DIRECTORIES +\
+    ["bbmap", "bowtie", "bowtie2", "minimap2", "novoalign", "twobit", "bismark",
+     "snap", "star", "seq"]
 DEFAULT_INDEXES = ["rtg"]
 
 Tool = collections.namedtuple("Tool", ["name", "fname"])
@@ -57,7 +58,7 @@ def upgrade_bcbio(args):
     args = add_install_defaults(args)
     if args.upgrade in ["stable", "system", "deps", "development"]:
         if args.upgrade == "development":
-            anaconda_dir = _update_conda_devel()
+            anaconda_dir = _update_conda_latest()
             _check_for_conda_problems()
             print("Upgrading bcbio-nextgen to latest development version")
             pip_bin = os.path.join(os.path.dirname(os.path.realpath(sys.executable)), "pip")
@@ -231,7 +232,7 @@ def _update_bcbiovm():
     """Update or install a local bcbiovm install with tools and dependencies.
     """
     print("## CWL support with bcbio-vm")
-    python_env = "python=3"
+    python_env = "python=3.6"
     conda_bin, env_name = _add_environment("bcbiovm", python_env)
     channels = _get_conda_channels(conda_bin)
     base_cmd = [conda_bin, "install", "--yes", "--name", env_name] + channels
@@ -287,6 +288,27 @@ def _update_conda_packages():
         os.remove(req_file)
     return os.path.dirname(os.path.dirname(conda_bin))
 
+def _update_conda_latest():
+    """Update to the latest bcbio conda package
+    """
+    conda_bin = _get_conda_bin()
+    output = subprocess.run([conda_bin, "search", "-c", "bioconda", "bcbio-nextgen"], stdout=subprocess.PIPE,
+                            stderr=subprocess.PIPE).stdout
+    lines = [l for l in output.decode().split("\n") if l]
+    latest = lines.pop()
+    tokens = latest.split()
+    conda_version = tokens[1].strip()
+    print(f"Detected {conda_version} as latest version of bcbio-nextgen on bioconda.")
+    channels = _get_conda_channels(conda_bin)
+    bcbio_version = version.__version__
+    if LooseVersion(bcbio_version) < LooseVersion(conda_version):
+        print(f"Installing bcbio {conda_version} from bioconda.")
+        subprocess.check_call([conda_bin, "install", "--quiet", "--yes"] + channels +
+                            [f"bcbio-nextgen>={conda_version}"])
+    else:
+        print(f"bcbio version {bcbio_version} is newer than the conda version {conda_version}, skipping upgrade from conda.")
+    return os.path.dirname(os.path.dirname(conda_bin))
+
 def _update_conda_devel():
     """Update to the latest development conda package.
     """
@@ -588,7 +610,7 @@ def _install_kraken_db(datadir, args):
     db = os.path.join(kraken, base)
     tooldir = args.tooldir or get_defaults()["tooldir"]
     requests.packages.urllib3.disable_warnings()
-    last_mod = urllib.request.urlopen(url).info().getheader('Last-Modified')
+    last_mod = urllib.request.urlopen(url).info().get('Last-Modified')
     last_mod = dateutil.parser.parse(last_mod).astimezone(dateutil.tz.tzutc())
     if os.path.exists(os.path.join(tooldir, "bin", "kraken")):
         if not os.path.exists(db):
@@ -710,7 +732,7 @@ def _datatarget_defaults(args, default_args):
         val = None
         if x == "data":
             val = "gemini"
-        elif x in ["cadd", "dbnsfp", "dbscsnv", "kraken", "gnomad"]:
+        elif x in ["dbnsfp", "dbscsnv", "kraken", "gnomad"]:
             val = x
         if val and val not in default_data:
             default_data.append(val)
@@ -768,7 +790,7 @@ def add_subparser(subparsers):
                         action="append", default=[], type=_check_toolplus)
     parser.add_argument("--datatarget", help="Data to install. Allows customization or install of extra data.",
                         action="append", default=[],
-                        choices=["variation", "rnaseq", "smallrna", "gemini", "cadd", "vep", "dbnsfp", "dbscsnv", "battenberg", "kraken", "ericscript", "gnomad"])
+                        choices=["variation", "rnaseq", "smallrna", "gemini", "vep", "dbnsfp", "dbscsnv", "battenberg", "kraken", "ericscript", "gnomad"])
     parser.add_argument("--genomes", help="Genomes to download",
                         action="append", default=[], choices=SUPPORTED_GENOMES)
     parser.add_argument("--aligners", help="Aligner indexes to download",
