@@ -4,14 +4,16 @@ functions to access the data dictionary in a clearer way
 
 import os
 import toolz as tz
-from bcbio.utils import file_exists, to_single_data
+from bcbio.utils import file_exists, to_single_data, deepish_copy
 from bcbio.log import logger
+from collections import namedtuple
 import sys
 
 LOOKUPS = {
     "config": {"keys": ['config']},
     "tmp_dir": {"keys": ['config', 'resources', 'tmp', 'dir']},
     "num_cores": {"keys": ['config', 'algorithm', 'num_cores'],
+
                   "default": 1},
     "svprioritize": {"keys": ['config', 'algorithm', 'svprioritize']},
     "effects_transcripts": {"keys": ["config", "algorithm", "effects_transcripts"], "default": "all"},
@@ -71,6 +73,8 @@ LOOKUPS = {
     "hetcaller": {"keys": ["config", "algorithm", "hetcaller"]},
     "variantcaller": {"keys": ['config', 'algorithm', 'variantcaller']},
     "variantcaller_order": {"keys": ['config', 'algorithm', 'variantcaller_order'], "default": 0},
+    "keep_duplicates": {"keys": ['config', 'algorithm', "keep_duplicates"], "default": False},
+    "keep_multimapped": {"keys": ['config', 'algorithm', "keep_multimapped"], "default": False},
     "svcaller": {"keys": ['config', 'algorithm', 'svcaller'], "default": [], "always_list": True},
     "jointcaller": {"keys": ['config', 'algorithm', 'jointcaller']},
     "hlacaller": {"keys": ['config', 'algorithm', 'hlacaller']},
@@ -102,6 +106,7 @@ LOOKUPS = {
     "isoform_to_gene": {"keys": ['isoform_to_gene']},
     "fusion_mode": {"keys": ['config', 'algorithm', 'fusion_mode']},
     "fusion_caller": {"keys": ['config', 'algorithm', 'fusion_caller']},
+    "known_fusions": {"keys": ['config', 'algorithm', 'known_fusions']},
     "dexseq_counts": {"keys": ['dexseq_counts']},
     "description": {"keys": ['description']},
     "aligner": {"keys": ['config', 'algorithm', 'aligner']},
@@ -135,12 +140,17 @@ LOOKUPS = {
     "rsem": {"keys": ["config", "algorithm", "rsem"], "default": False},
     "transcriptome_align": {"keys": ["config", "algorithm", "transcriptome_align"],
                             "default": False},
+    "quantify_genome_alignments": {"keys": ["config", "algorithm", "quantify_genome_alignments"],
+                             "default": False},
     "expression_caller": {"keys": ["config", "algorithm", "expression_caller"],
                           "default": [], "always_list": True},
     "fusion_caller": {"keys": ["config", "algorithm", "fusion_caller"], "default": []},
     "spikein_fasta" : {"keys": ["config", "algorithm", "spikein_fasta"], "default": None},
     "transcriptome_bam": {"keys": ["transcriptome_bam"]},
     "junction_bed": {"keys": ["junction_bed"]},
+    "starjunction": {"keys": ["starjunction"]},
+    "chimericjunction": {"keys": ["chimericjunction"]},
+    "star_log": {"keys": ["STAR", "log"], "default": None},
     "fpkm_isoform": {"keys": ["fpkm_isoform"]},
     "fpkm": {"keys": ["fpkm"]},
     "galaxy_dir": {"keys": ["dirs", "galaxy"]},
@@ -171,6 +181,8 @@ LOOKUPS = {
     "save_diskspace": {"keys": ["config", "algorithm", "save_diskspace"]},
     "salmon": {"keys": ["salmon"]},
     "umi_type": {"keys": ["config", "algorithm", "umi_type"]},
+    "correct_umis": {"keys": ["config", "algorithm", "correct_umis"]},
+    "use_lowfreq_filter": {"keys": ["config", "algorithm", "use_lowfreq_filter"]},
     "sample_barcodes": {"keys": ["config", "algorithm", "sample_barcodes"]},
     "cellular_barcodes": {"keys": ["config", "algorithm", "cellular_barcodes"],
                           "default": []},
@@ -181,6 +193,7 @@ LOOKUPS = {
                                     "default": 1},
     "demultiplexed": {"keys": ["config", "algorithm", "demultiplexed"]},
     "kallisto_quant": {"keys": ["kallisto_quant"]},
+    "tximport": {"keys": ["tximport"], "default": None}, 
     "salmon_dir": {"keys": ["salmon_dir"]},
     "salmon_fraglen_file": {"keys": ["salmon_fraglen_file"]},
     "sailfish": {"keys": ["sailfish"]},
@@ -195,6 +208,7 @@ LOOKUPS = {
                           "default": False},
     "joint_group_size": {"keys": ["config", "algorithm", "joint_group_size"],
                          "default": 200},
+    "arriba": {"keys": ["arriba"], "default": {}},
     "report": {"keys": ["config", "algorithm", "report"]},
     "work_bam": {"keys": ["work_bam"]},
     "deduped_bam": {"keys": ["deduped_bam"]},
@@ -202,6 +216,7 @@ LOOKUPS = {
     "disc_bam": {"keys": ["work_bam_plus", "disc"]},
     "sr_bam": {"keys": ["work_bam_plus", "sr"]},
     "peddy_report": {"keys": ["peddy_report"]},
+    "antibody": {"keys": ["config", "algorithm", "antibody"], "default": ""},
     "tools_off": {"keys": ["config", "algorithm", "tools_off"], "default": [], "always_list": True},
     "tools_on": {"keys": ["config", "algorithm", "tools_on"], "default": [], "always_list": True},
     "cwl_reporting": {"keys": ["config", "algorithm", "cwl_reporting"]},
@@ -250,6 +265,16 @@ def get_umi_consensus(data):
             "Using consensus UMI inputs requires marking duplicates"
         return umi
 
+def get_correct_umis(data):
+    """
+    Do we need to correct UMIs with a whitelist?
+    """
+    umi_whitelist = tz.get_in(["config", "algorithm", "correct_umis"], data)
+    if umi_whitelist:
+        return True
+    else:
+        return False
+
 def get_dexseq_gff(config, default=None):
     """
     some older versions of the genomes have the DEXseq gff file as
@@ -354,7 +379,9 @@ def update_summary_qc(data, key, base=None, secondary=None):
     stick files into summary_qc if you want them propagated forward
     and available for multiqc
     """
-    summary = get_summary_qc(data, {})
+    summary = deepish_copy(get_summary_qc(data, {}))
+    if key in summary:
+        return data
     if base and secondary:
         summary[key] = {"base": base, "secondary": secondary}
     elif base:
@@ -372,3 +399,15 @@ def has_variantcalls(data):
     variant_pipeline = analysis.startswith(("standard", "variant", "variant2"))
     variantcaller = get_variantcaller(data)
     return variant_pipeline or variantcaller
+
+def get_algorithm_keys():
+    """
+    returns a list of all defined keys under the algorithm section
+    """
+    keys = []
+    for k, v in LOOKUPS.items():
+        if not "algorithm" in v["keys"]:
+            continue
+        if k == v["keys"][2]:
+            keys.append(k)
+    return keys
