@@ -31,12 +31,17 @@ def run_main(workdir, config_file=None, fc_dir=None, run_info_yaml=None,
     """Run variant analysis, handling command line options.
     """
     # Set environment to standard to use periods for decimals and avoid localization
-    os.environ["LC_ALL"] = "C"
-    os.environ["LC"] = "C"
-    os.environ["LANG"] = "C"
+    locale_to_use = utils.get_locale()
+    os.environ["LC_ALL"] = locale_to_use
+    os.environ["LC"] = locale_to_use
+    os.environ["LANG"] = locale_to_use
     workdir = utils.safe_makedir(os.path.abspath(workdir))
     os.chdir(workdir)
     config, config_file = config_utils.load_system_config(config_file, workdir)
+    parallel = log.create_base_logger(config, parallel)
+    log.setup_local_logging(config, parallel)
+    logger.info(f"System YAML configuration: {os.path.abspath(config_file)}.")
+    logger.info(f"Locale set to {locale_to_use}.")
     if config.get("log_dir", None) is None:
         config["log_dir"] = os.path.join(workdir, DEFAULT_LOG_DIR)
     if parallel["type"] in ["local", "clusterk"]:
@@ -76,9 +81,6 @@ def _run_toplevel(config, config_file, work_dir, parallel,
     fc_dir -- Directory of fastq files to process
     run_info_yaml -- YAML configuration file specifying inputs to process
     """
-    parallel = log.create_base_logger(config, parallel)
-    log.setup_local_logging(config, parallel)
-    logger.info("System YAML configuration: %s" % os.path.abspath(config_file))
     dirs = run_info.setup_directories(work_dir, fc_dir, config, config_file)
     config_file = os.path.join(dirs["config"], os.path.basename(config_file))
     pipelines, config = _pair_samples_with_pipelines(run_info_yaml, config)
@@ -273,7 +275,12 @@ def rnaseqpipeline(config, run_info_yaml, parallel, dirs, samples):
             for sample in samples:
                 run_parallel("upload_samples_project", [sample])
         with profile.report("bcbioRNAseq loading", dirs):
-            run_parallel("run_bcbiornaseqload", [sample])
+            tools_on = dd.get_in_samples(samples, dd.get_tools_on)
+            bcbiornaseq_on = tools_on and "bcbiornaseq" in tools_on
+            if bcbiornaseq_on and len(samples) == 1:
+                logger.warn("bcbioRNASeq does not work with just one sample, skipping.")
+            else:
+                run_parallel("run_bcbiornaseqload", [sample])
     logger.info("Timing: finished")
     return samples
 
@@ -391,6 +398,39 @@ def chipseqpipeline(config, run_info_yaml, parallel, dirs, samples):
     return samples
 
 
+def wgbsseqpipeline(config, run_info_yaml, parallel, dirs, samples):
+    with prun.start(_wres(parallel, ["fastqc", "picard"], ensure_mem={"fastqc" : 4}),
+                    samples, config, dirs, "trimming") as run_parallel:
+        with profile.report("organize samples", dirs):
+            samples = run_parallel("organize_samples", [[dirs, config, run_info_yaml,
+                                                            [x[0]["description"] for x in samples]]])
+            samples = run_parallel("prepare_sample", samples)
+            samples = run_parallel("trim_bs_sample", samples)
+
+    with prun.start(_wres(parallel, ["aligner", "bismark", "picard", "samtools"]),
+                    samples, config, dirs, "multicore",
+                    multiplier=alignprep.parallel_multiplier(samples)) as run_parallel:
+        with profile.report("alignment", dirs):
+            samples = run_parallel("process_alignment", samples)
+
+    with prun.start(_wres(parallel, ['samtools']), samples, config, dirs,
+                    'deduplication') as run_parallel:
+        with profile.report('deduplicate', dirs):
+            samples = run_parallel('deduplicate_bismark', samples)
+
+    with prun.start(_wres(parallel, ["caller"], ensure_mem={"caller": 5}),
+                    samples, config, dirs, "multicore2",
+                    multiplier=24) as run_parallel:
+        with profile.report("cpg calling", dirs):
+            samples = run_parallel("cpg_calling", samples)
+
+    # with prun.start(_wres(parallel, ["picard", "fastqc", "samtools"]),
+    #                 samples, config, dirs, "qc") as run_parallel:
+    #     with profile.report("quality control", dirs):
+    #         samples = qcsummary.generate_parallel(samples, run_parallel)
+    return samples
+
+
 def rnaseq_prep_samples(config, run_info_yaml, parallel, dirs, samples):
     """
     organizes RNA-seq and small-RNAseq samples, converting from BAM if
@@ -468,6 +508,7 @@ SUPPORTED_PIPELINES = {"variant2": variant2pipeline,
                        "rna-seq": rnaseqpipeline,
                        "smallrna-seq": smallrnaseqpipeline,
                        "chip-seq": chipseqpipeline,
+                       "wgbs-seq": wgbsseqpipeline,
                        "fastrna-seq": fastrnaseqpipeline,
                        "scrna-seq": singlecellrnaseqpipeline}
 
