@@ -2,16 +2,18 @@ import os
 import sys
 from bcbio.rnaseq import (featureCounts, cufflinks, oncofuse, count, dexseq,
                           express, variation, stringtie, sailfish, spikein, pizzly, ericscript,
-                          kallisto, salmon, singlecellexperiment)
+                          kallisto, salmon, singlecellexperiment, arriba)
 from bcbio.ngsalign import bowtie2, alignprep
 from bcbio.variation import effects, joint, multi, population, vardict
 import bcbio.pipeline.datadict as dd
-from bcbio.utils import filter_missing, flatten, to_single_data, file_exists
+from bcbio.utils import filter_missing, flatten, to_single_data, file_exists, Rscript_cmd, safe_makedir
 from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
+from bcbio.provenance import do
 
 def fast_rnaseq(samples, run_parallel):
-    samples = run_parallel("run_salmon_index", [samples])
+    to_index = determine_indexes_to_make(samples)
+    run_parallel("run_salmon_index", [to_index])
     samples = run_parallel("run_salmon_reads", samples)
     samples = run_parallel("run_counts_spikein", samples)
     samples = spikein.combine_spikein(samples)
@@ -178,7 +180,23 @@ def quantitate(data):
     else:
         data["quant"]["fusion"] = None
     if "salmon" in dd.get_expression_caller(data):
-        data = to_single_data(salmon.run_salmon_reads(data)[0])
+        if dd.get_quantify_genome_alignments(data): 
+            if dd.get_aligner(data).lower() != "star":
+                if dd.get_genome_build(data) == "hg38":
+                    logger.warning("Whole genome alignment-based Salmon quantification is "
+                         "only supported for the STAR aligner. Since this is hg38 we will fall "
+                         "back to the decoy method")
+                    data = to_single_data(salmon.run_salmon_decoy(data)[0])
+                else:
+                    logger.warning(
+                         "Whole genome alignment-based Salmon quantification is "
+                         "only supported for the STAR aligner. Falling back to the "
+                         "transcriptome-only method.")
+                    data = to_single_data(salmon.run_salmon_reads(data)[0])
+            else:
+                data = to_single_data(salmon.run_salmon_bam(data)[0])
+        else:
+            data = to_single_data(salmon.run_salmon_reads(data)[0])
         data["quant"]["tsv"] = data["salmon"]
         data["quant"]["hdf5"] = os.path.join(os.path.dirname(data["salmon"]), "abundance.h5")
     return [[data]]
@@ -189,6 +207,7 @@ def quantitate_expression_parallel(samples, run_parallel):
     take advantage of the threaded run_parallel environment
     """
     data = samples[0][0]
+    to_index = determine_indexes_to_make(samples)
     samples = run_parallel("generate_transcript_counts", samples)
     if "cufflinks" in dd.get_expression_caller(data):
         samples = run_parallel("run_cufflinks", samples)
@@ -197,14 +216,31 @@ def quantitate_expression_parallel(samples, run_parallel):
     if ("kallisto" in dd.get_expression_caller(data) or
         dd.get_fusion_mode(data) or
         "pizzly" in dd.get_fusion_caller(data, [])):
-        samples = run_parallel("run_kallisto_index", [samples])
+        run_parallel("run_kallisto_index", [to_index])
         samples = run_parallel("run_kallisto_rnaseq", samples)
     if "sailfish" in dd.get_expression_caller(data):
-        samples = run_parallel("run_sailfish_index", [samples])
+        run_parallel("run_sailfish_index", [to_index])
         samples = run_parallel("run_sailfish", samples)
+
     # always run salmon
-    samples = run_parallel("run_salmon_index", [samples])
-    samples = run_parallel("run_salmon_reads", samples)
+    run_parallel("run_salmon_index", [to_index])
+    if dd.get_quantify_genome_alignments(data):
+        if dd.get_aligner(data).lower() != "star":
+            if dd.get_genome_build(data) == "hg38":
+                logger.warning("Whole genome alignment-based Salmon quantification is "
+                   "only supported for the STAR aligner. Since this is hg38 we will fall "
+                   "back to the decoy method")
+                samples = run_parallel("run_salmon_decoy", samples)
+            else:
+                logger.warning(
+                   "Whole genome alignment-based Salmon quantification is "
+                   "only supported for the STAR aligner. Falling back to the "
+                   "transcriptome-only method.")
+                samples = run_parallel("run_salmon_reads", samples)
+        else:
+            samples = run_parallel("run_salmon_bam", samples)
+    else:
+        samples = run_parallel("run_salmon_reads", samples)
 
     samples = run_parallel("detect_fusions", samples)
     return samples
@@ -231,6 +267,8 @@ def detect_fusions(data):
                               "json": os.path.join(pizzly_dir, "%s.json" % dd.get_sample_name(data))}
     if "ericscript" in fusion_caller:
         ericscript_dir = ericscript.run(data)
+    if "arriba" in fusion_caller:
+        data = arriba.run_arriba(data)
     return [[data]]
 
 def quantitate_expression_noparallel(samples, run_parallel):
@@ -441,6 +479,7 @@ def combine_files(samples):
     else:
         dexseq_combined = None
     samples = spikein.combine_spikein(samples)
+    tximport = load_tximport(data)
     updated_samples = []
     for data in dd.sample_data_iterator(samples):
         if combined:
@@ -460,5 +499,53 @@ def combine_files(samples):
             data = dd.set_dexseq_counts(data, dexseq_combined_file)
         if gtf_file:
             data = dd.set_tx2gene(data, tx2gene_file)
+        data = dd.set_tximport(data, tximport)
         updated_samples.append([data])
     return updated_samples
+
+def determine_indexes_to_make(samples):
+    """
+    returns a subset of the samples that have different indexes in them to make sure we only
+    make each index once
+    """
+    samples = [to_single_data(x) for x in samples]
+    indexes = set()
+    tomake = []
+    for data in samples:
+        out_dir = os.path.join(dd.get_work_dir(data), "inputs", "transcriptome")
+        out_stem = os.path.join(out_dir, dd.get_genome_build(data))
+        if dd.get_disambiguate(data):
+            out_stem = "-".join([out_stem] + (dd.get_disambiguate(data) or []))
+        if dd.get_disambiguate(data):
+            out_stem = "-".join([out_stem] + (dd.get_disambiguate(data) or []))
+        combined_file = out_stem + ".fa"
+        if combined_file not in indexes:
+            tomake.append(data)
+            indexes.add(combined_file)
+    return tomake
+
+def load_tximport(data):
+    rcmd = Rscript_cmd()
+    salmon_dir = os.path.join(dd.get_work_dir(data), "salmon")
+    tx2gene_file = os.path.join(dd.get_work_dir(data), "inputs", "transcriptome", "tx2gene.csv")
+    out_dir = os.path.join(salmon_dir, "combined")
+    safe_makedir(out_dir)
+    tpm_file = os.path.join(out_dir, "tximport-tpm.csv")
+    counts_file = os.path.join(out_dir, "tximport-counts.csv")
+    if file_exists(tpm_file) and file_exists(counts_file):
+        return {"gene_tpm": tpm_file,
+                "gene_counts": counts_file}
+    with file_transaction(tpm_file) as tx_tpm_file, file_transaction(counts_file) as tx_counts_file:
+        render_string = (
+            f'library(tidyverse);'
+            f'salmon_files = list.files("{salmon_dir}", pattern="quant.sf", recursive=TRUE, full.names=TRUE);'
+            f'tx2gene = readr::read_csv("{tx2gene_file}", col_names=c("transcript", "gene")); '
+            f'samples = basename(dirname(dirname(salmon_files)));'
+            f'names(salmon_files) = samples;'
+            f'txi = tximport::tximport(salmon_files, type="salmon", tx2gene=tx2gene, countsFromAbundance="lengthScaledTPM");'
+            f'readr::write_csv(txi$counts %>% as.data.frame() %>% tibble::rownames_to_column("gene"), "{tx_counts_file}");'
+            f'readr::write_csv(txi$abundance %>% as.data.frame() %>% tibble::rownames_to_column("gene"), "{tx_tpm_file}");'
+        )
+        do.run([rcmd, "--vanilla", "-e", render_string], f"Loading tximport.")
+    return {"gene_tpm": tpm_file,
+            "gene_counts": counts_file}
