@@ -25,7 +25,6 @@ def combine_count_files(files, out_file=None, ext=".fpkm"):
     if not out_file:
         out_dir = os.path.join(os.path.dirname(files[0]))
         out_file = os.path.join(out_dir, "combined.counts")
-
     if file_exists(out_file):
         return out_file
     logger.info("Combining count files into %s." % out_file)
@@ -36,14 +35,20 @@ def combine_count_files(files, out_file=None, ext=".fpkm"):
         if i == 0:
             with open(f) as in_handle:
                 for line in in_handle:
-                    rname, val = line.strip().split("\t")
-                    row_names.append(rname)
-                    vals.append(val)
+                    if not line.strip().startswith("#"):
+                        rname, val = line.strip().split("\t")
+                        row_names.append(rname)
+                        vals.append(val)
         else:
             with open(f) as in_handle:
                 for line in in_handle:
-                    _, val = line.strip().split("\t")
-                    vals.append(val)
+                    if not line.strip().startswith("#"):
+                        try:
+                            _, val = line.strip().split("\t")
+                        except ValueError:
+                            print(f, line)
+                            raise
+                        vals.append(val)
         col_vals[col_names[i]] = vals
 
     df = pd.DataFrame(col_vals, index=row_names)
@@ -73,7 +78,7 @@ def annotate_combined_count_file(count_file, gtf_file, out_file=None):
     except KeyError:
         return None
 
-    df = pd.io.parsers.read_table(count_file, sep="\t", index_col=0, header=0)
+    df = pd.io.parsers.read_csv(count_file, sep="\t", index_col=0, header=0)
 
     df['symbol'] = df.apply(lambda x: symbol_lookup.get(x.name, ""), axis=1)
     df.to_csv(out_file, sep="\t", index_label="id")
