@@ -20,7 +20,7 @@ def ipc_fn(parallel):
         else:
             mincores = int(math.ceil(mincores / float(cores_per_job)))
             num_jobs = int(math.ceil(num_jobs / float(mincores)))
-    print "num of jobs: %s with %s engines" % (num_jobs, mincores)
+    print(f"num of jobs: {num_jobs} with {mincores} engines")
 
 
 def ipython_fn(parallel, config):
@@ -34,7 +34,7 @@ def ipython_fn(parallel, config):
         # if we have less scheduled cores than per machine, use the scheduled count
         if num_engines > parallel["cores"]:
             num_engines = parallel["cores"]
-        print "common %s cores_per_job %s cores %s" % (common_cores, parallel['cores_per_job'], num_engines)
+        print(f"common {common_cores} cores_per_job {parallel['cores_per_job']} cores {num_engines}")
         if (parallel['cores_per_job'] * num_engines) > common_cores:
             num_engines = int(math.floor(float(common_cores) / parallel['cores_per_job']))
 
@@ -104,20 +104,20 @@ if __name__ == "__main__":
     else:
         if utils.file_exists(args.sys_info):
             sysinfo = yaml.safe_load(open(args.sys_info))[0]
-    print "system info %s" % sysinfo
+    print(f"system info {sysinfo}")
     samples = []
     pipelines, config = _pair_samples_with_pipelines(args.yaml_file, config)
     for s in pipelines:
         samples = [item for item in pipelines[s]]
-    print "number of samples %s" % len(samples)
-    print "after calculate fn"
+    print(f"number of samples {len(samples)}") % len(samples)
+    print("after calculate fn")
     parallel = resources.calculate(parallel, samples, sysinfo, config)
-    print parallel
+    print(parallel)
     if args.fixed:
-        print "after fixed ipython fn"
+        print("after fixed ipython fn")
         parallel = ipython_fn(parallel, config)
     else:
-        print "after ipython fn"
+        print("after ipython fn")
         parallel = ipython_current(parallel, config)
-    print parallel
+    print(parallel)
     ipc_fn(parallel)
